import * as tslib_1 from "tslib";
import classNames from "classnames";
import clamp from "lodash-es/clamp";
import React, { useEffect, useLayoutEffect, useRef, useState } from "react";
import { TabBarRoot } from "./index";
export function ScrollableTabBar(props) {
    var wrapRef = useRef(null);
    var innerRef = useRef(null);
    var _a = props.tabsInfo, tabsInfo = _a === void 0 ? [] : _a, scrollToRef = props.scrollToRef;
    var _b = useState(0), left = _b[0], setLeft = _b[1];
    var _c = useState(false), overflow = _c[0], setOverflow = _c[1];
    function checkOverflow() {
        var wrap = wrapRef.current;
        var inner = innerRef.current;
        // Tips: 注意元素的过度属性, 包括tab节点的过度, 都会影响计算宽度
        setOverflow(inner.scrollWidth > wrap.clientWidth);
    }
    function getTabWidth() {
        var inner = innerRef.current;
        var clientWidth = inner.clientWidth;
        var tabbarWidth = clientWidth;
        var max = inner.scrollWidth - clientWidth;
        return [tabbarWidth, max];
    }
    function findLeft(tabKey) {
        var inner = innerRef.current;
        var tab = inner.querySelector("[data-tab-key=\"" + tabKey + "\"]");
        if (!tab) {
            return [0, tab];
        }
        var _a = getTabWidth(), max = _a[1];
        return [clamp(tab.offsetLeft, 0, max), tab];
    }
    /**
     * 滚动到指定tab
     * @param tabKey 默认当前激活tabkey
     */
    function scrollTo(tabKey) {
        if (tabKey === void 0) { tabKey = props.activeKey; }
        setLeft(findLeft(tabKey)[0]);
    }
    function prev() {
        var _a = getTabWidth(), tabbarWidth = _a[0], max = _a[1];
        var distance = clamp(left - tabbarWidth, 0, max);
        var first = tabsInfo[0];
        var _b = findLeft(first ? first.tabKey : null), tab = _b[1];
        if (tab && distance - tab.clientWidth < 0) {
            // 还剩下不到一个tab的距离, 则直接定位到第一个
            setLeft(0);
        }
        else {
            setLeft(distance);
        }
    }
    function next() {
        var _a = getTabWidth(), tabbarWidth = _a[0], max = _a[1];
        var distance = clamp(left + tabbarWidth, 0, max);
        var last = tabsInfo[tabsInfo.length - 1];
        var _b = findLeft(last ? last.tabKey : null), lastLeft = _b[0], tab = _b[1];
        if (tab && distance + tab.clientWidth > lastLeft) {
            // 接近最后一个tab, 则直接滚动到最后一个
            setLeft(lastLeft);
        }
        else {
            setLeft(distance);
        }
    }
    useEffect(function () {
        if (scrollToRef) {
            scrollToRef.current = scrollTo;
        }
    }, []);
    useLayoutEffect(function () {
        // TODO: #1 监听 window.resize, 并且用节流函数
        checkOverflow();
        scrollTo();
    }, [props.tabsInfo.length]);
    return (React.createElement("div", { className: classNames("scrollable-tabbar", { overflow: overflow }), ref: wrapRef },
        React.createElement("span", { className: "tabs-arrow tab-prev", onClick: prev },
            React.createElement("span", { className: "tabs-icon" })),
        React.createElement("span", { className: "tabs-arrow tab-next", onClick: next },
            React.createElement("span", { className: "tabs-icon" })),
        React.createElement("div", { className: "scrollable-tabbar__wrap" },
            React.createElement(TabBarRoot, tslib_1.__assign({}, props, { className: "scrollable_inner", style: { transform: "translateX(-" + left + "px)" }, ref: innerRef })))));
}
export default React.memo(ScrollableTabBar);
//# sourceMappingURL=ScrollableTabBar.js.map