import classNames from "classnames";
import React, { useCallback } from "react";
import { useControll } from "utils-hooks";
import TabBarRoot from "./TabBarRoot";
import TabContentRoot from "./TabContentRoot";
import { TabsContext } from "./TabsContext";
var DEFAULT_KEY = "-1";
var DEFAULT_RenderTabBar = function () { return React.createElement(TabBarRoot, null); };
var DEFAULT_renderTabContent = function () { return React.createElement(TabContentRoot, null); };
function findDefaultTabKey(children) {
    var firstTabKey = DEFAULT_KEY;
    React.Children.forEach(children, function (d) {
        if (firstTabKey === DEFAULT_KEY) {
            firstTabKey = d.props.tabKey;
        }
    });
    return firstTabKey;
}
function findTabsInfo(children, activeKey) {
    var tabsInfo = React.Children.map(children, function (d) {
        var _a = d.props, tabKey = _a.tabKey, tab = _a.tab, disabled = _a.disabled;
        return {
            tabKey: tabKey,
            tab: tab,
            panel: d,
            disabled: disabled,
            active: activeKey === tabKey
        };
    }) || [];
    return tabsInfo;
}
export function Tabs(props) {
    var _a = props.prefixCls, prefixCls = _a === void 0 ? "xy-tabs" : _a, className = props.className, style = props.style, onChange = props.onChange, _b = props.renderTabBar, renderTabBar = _b === void 0 ? DEFAULT_RenderTabBar : _b, _c = props.renderTabContent, renderTabContent = _c === void 0 ? DEFAULT_renderTabContent : _c, children = props.children, lazy = props.lazy, _d = props.reverse, reverse = _d === void 0 ? false : _d, destroyInactiveTabPane = props.destroyInactiveTabPane;
    var _e = useControll(props, "activeKey", "defaultActiveKey", findDefaultTabKey(children)), activeKey = _e[0], setActiveKey = _e[1], isControll = _e[2];
    var tabsInfo = findTabsInfo(children, activeKey);
    var handleActiveClick = useCallback(function (key, event) {
        if (!isControll) {
            setActiveKey(key);
        }
        if (onChange) {
            onChange(key);
        }
        if (props.onTabClick) {
            props.onTabClick(activeKey, event);
        }
    }, []);
    function doRenderTabBar() {
        return React.cloneElement(renderTabBar(), { prefixCls: prefixCls, activeKey: activeKey, tabsInfo: tabsInfo, onTabClick: handleActiveClick, key: "tabbar" });
    }
    function doRenderTabContent() {
        return React.cloneElement(renderTabContent(), { prefixCls: prefixCls, activeKey: activeKey, tabsInfo: tabsInfo, lazy: lazy, destroyInactiveTabPane: destroyInactiveTabPane, key: "tabcontent" });
    }
    var childrens = [doRenderTabBar(), doRenderTabContent()];
    return (React.createElement(TabsContext.Provider, { value: { activeKey: activeKey, setActiveKey: setActiveKey } },
        React.createElement("div", { className: classNames(prefixCls, className), style: style, "data-active-key": activeKey }, reverse ? childrens.reverse() : childrens)));
}
export default React.memo(Tabs);
//# sourceMappingURL=Tabs.js.map